<?php
/**
 * @package		Joomla.Site
 * @subpackage	mod_articles_archive
 * @copyright	Copyright (C) 2005 - 2012 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;
?>
<?php if (!empty($list)) :?>

<ul class="archive-module nav nav-list">
	<?php foreach ($list as $item) : ?>
	<li> <a href="<?php echo $item->link; ?>"><i class="icon-arrow-right"></i> <?php echo $item->text; ?> </a> </li>
	<?php endforeach; ?>
</ul>
<?php endif; ?>
